==> ejc-procost-impl-3.0.0-20230804.095107-209-sources.jar: com/ejianc/business/procost/bean/HandshareDetailEntity.java <==
package com.ejianc.business.procost.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 成本单据明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procost_handshare_detail")
public class HandshareDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="handshare_id")
    private Long handshareId; // 主表Id
    @TableField(value="wbs_id")
    private Long wbsId; // 核算对象主键
    @TableField(value="wbs_code")
    private String wbsCode; // 核算对象编码
    @TableField(value="wbs_name")
    private String wbsName; // 核算对象名称
    @TableField(value="subject_id")
    private Long subjectId; // 科目主键
    @TableField(value="subject_code")
    private String subjectCode; // 科目编号
    @TableField(value="subject_name")
    private String subjectName; // 科目名称
    @TableField(value="happen_tax_mny")
    private BigDecimal happenTaxMny; // 发生成本(含税)
    @TableField(value="happen_mny")
    private BigDecimal happenMny; // 发生成本(不含税)
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="create_user_name")
    private String createUserName; // 创建人名称
    @TableField(value="subject_parent_id")
    private Long subjectParentId; // 科目上级主键


    public Long getSubjectParentId() {
        return subjectParentId;
    }

    public void setSubjectParentId(Long subjectParentId) {
        this.subjectParentId = subjectParentId;
    }

    public Long getHandshareId() {
        return handshareId;
    }

    public void setHandshareId(Long handshareId) {
        this.handshareId = handshareId;
    }
    public Long getWbsId() {
        return wbsId;
    }

    public void setWbsId(Long wbsId) {
        this.wbsId = wbsId;
    }
    public String getWbsCode() {
        return wbsCode;
    }

    public void setWbsCode(String wbsCode) {
        this.wbsCode = wbsCode;
    }
    public String getWbsName() {
        return wbsName;
    }

    public void setWbsName(String wbsName) {
        this.wbsName = wbsName;
    }
    public Long getSubjectId() {
        return subjectId;
    }

    public void setSubjectId(Long subjectId) {
        this.subjectId = subjectId;
    }
    public String getSubjectCode() {
        return subjectCode;
    }

    public void setSubjectCode(String subjectCode) {
        this.subjectCode = subjectCode;
    }
    public String getSubjectName() {
        return subjectName;
    }

    public void setSubjectName(String subjectName) {
        this.subjectName = subjectName;
    }
    public BigDecimal getHappenTaxMny() {
        return happenTaxMny;
    }

    public void setHappenTaxMny(BigDecimal happenTaxMny) {
        this.happenTaxMny = happenTaxMny;
    }
    public BigDecimal getHappenMny() {
        return happenMny;
    }

    public void setHappenMny(BigDecimal happenMny) {
        this.happenMny = happenMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    
}

==> ejc-procost-impl-3.0.0-20230906.070514-226-sources.jar: com/ejianc/business/procost/bean/HandshareDetailEntity.java <==
package com.ejianc.business.procost.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 成本单据明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procost_handshare_detail")
public class HandshareDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="handshare_id")
    private Long handshareId; // 主表Id
    @TableField(value="wbs_id")
    private Long wbsId; // 核算对象主键
    @TableField(value="wbs_code")
    private String wbsCode; // 核算对象编码
    @TableField(value="wbs_name")
    private String wbsName; // 核算对象名称
    @TableField(value="subject_id")
    private Long subjectId; // 科目主键
    @TableField(value="subject_code")
    private String subjectCode; // 科目编号
    @TableField(value="subject_name")
    private String subjectName; // 科目名称
    @TableField(value="happen_tax_mny")
    private BigDecimal happenTaxMny; // 发生成本(含税)
    @TableField(value="happen_mny")
    private BigDecimal happenMny; // 发生成本(不含税)
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="create_user_name")
    private String createUserName; // 创建人名称
    @TableField(value="subject_parent_id")
    private Long subjectParentId; // 科目上级主键


    @TableField(value="detail_code")
    private String detailCode; // 清单编码
    @TableField(value="detail_name")
    private String detailName; // 清单名称

    public String getDetailCode() {
        return detailCode;
    }

    public void setDetailCode(String detailCode) {
        this.detailCode = detailCode;
    }

    public String getDetailName() {
        return detailName;
    }

    public void setDetailName(String detailName) {
        this.detailName = detailName;
    }

    public Long getSubjectParentId() {
        return subjectParentId;
    }

    public void setSubjectParentId(Long subjectParentId) {
        this.subjectParentId = subjectParentId;
    }

    public Long getHandshareId() {
        return handshareId;
    }

    public void setHandshareId(Long handshareId) {
        this.handshareId = handshareId;
    }
    public Long getWbsId() {
        return wbsId;
    }

    public void setWbsId(Long wbsId) {
        this.wbsId = wbsId;
    }
    public String getWbsCode() {
        return wbsCode;
    }

    public void setWbsCode(String wbsCode) {
        this.wbsCode = wbsCode;
    }
    public String getWbsName() {
        return wbsName;
    }

    public void setWbsName(String wbsName) {
        this.wbsName = wbsName;
    }
    public Long getSubjectId() {
        return subjectId;
    }

    public void setSubjectId(Long subjectId) {
        this.subjectId = subjectId;
    }
    public String getSubjectCode() {
        return subjectCode;
    }

    public void setSubjectCode(String subjectCode) {
        this.subjectCode = subjectCode;
    }
    public String getSubjectName() {
        return subjectName;
    }

    public void setSubjectName(String subjectName) {
        this.subjectName = subjectName;
    }
    public BigDecimal getHappenTaxMny() {
        return happenTaxMny;
    }

    public void setHappenTaxMny(BigDecimal happenTaxMny) {
        this.happenTaxMny = happenTaxMny;
    }
    public BigDecimal getHappenMny() {
        return happenMny;
    }

    public void setHappenMny(BigDecimal happenMny) {
        this.happenMny = happenMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    
}
